;**********************************************************************
;   CW Beacon software  				                              *
;   	  															  *
;	
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    Beacon_software.asm                     	      *
;    Date:   		2011-07-10                                        *
;    Version: 		01                                                *
;                                                                     *
;    Author:     	SM7ZFB		                                      *
;                                                  					  *
;                                                                     * 
;                                                                     *
;**********************************************************************
;                                                                     *
;    Debug status:                                                    *
;                                                                     *
;    Tested, works ok                                                 *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;                                                                     *
;		
;       Build for PIC10F206 in DIL8 with Microchip MPLAB IDE v8.60               
;                                                                           
;                           DIL8
;                      ----------------------
;                     |                      |  
;                  1  |  NC          GP3/PB  | 8
;                     |                      |  
;                  2  |  VCC            GND  | 7
;                     |                      |  
;                  3  | GP2              NC  | 6  
;                     |                      |  
;                  4  | GP1/Key/LED     GP0  | 5 
;                      ----------------------
;                                                                     *
;                                                                     *
;                                                                     *
;**********************************************************************


	#include <p10F206.inc>        ; processor specific variable definitions

	__CONFIG   _MCLRE_ON & _CP_OFF & _WDT_OFF & _IntRC_OSC



; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file. 
; See respective data sheet for additional information on configuration word.




;************************** VARIABLE DEFINITIONS ******************************

	cblock 0x10

		del_1			; delaycounter 1
		delay_2			; delaycounter 2
		delay_3			; delaycounter 3
		delay_4			; delaycounter 4

	endc

;*************************** DEFINE STATEMENTS ********************************


#define output			GPIO,1			; CW key

;****************************** START OF CODE *********************************

	ORG     0x0             ; coding begins here


;******************************************************************************
; InitializeSFRs - Initialize Special Function Registers
;
;******************************************************************************


	bcf CMCON0,3
	movlw 0xdf
	option


	movlw	b'00001000'		; configure GPIO1 as output,GPIO0, GPIO2, GPIO3 as input
	tris	GPIO

;******************************************************************************
;	CW character macros
;******************************************************************************

;	dot   = 1T key down + 1T key up
;	dot_  = 1T key down + 3T key up (for inter-character space)
;	dash  = 3T key down + 1T key up
;	dash_ = 3T key down + 3T key up (for inter-character space)

__A	macro
	call	dot
	call	dash_
	endm

__B	macro
	call	dash
	call	dot
	call	dot
	call	dot_
	endm

__C	macro
	call	dash
	call	dot
	call	dash
	call	dot_
	endm

__D	macro
	call	dash
	call	dot
	call	dot_
	endm

__E	macro
	call	dot_
	endm

__F	macro
	call	dot
	call	dot
	call	dash
	call	dot_
	endm

__G	macro
	call	dash
	call	dash
	call	dot_
	endm

__H	macro
	call	dot
	call	dot
	call	dot
	call	dot_
	endm

__I	macro
	call	dot
	call	dot_
	endm

__J	macro
	call	dot
	call	dash
	call	dash
	call	dash_
	endm

__K	macro
	call	dash
	call	dot
	call	dash_
	endm

__L	macro
	call	dot
	call	dash
	call	dot
	call	dot_
	endm

__M	macro
	call	dash
	call	dash_
	endm

__N	macro
	call	dash
	call	dot_
	endm

__O	macro
	call	dash
	call	dash
	call	dash_
	endm

__P	macro
	call	dot
	call	dash
	call	dash
	call	dot_
	endm

__Q	macro
	call	dash
	call	dash
	call	dot
	call	dash_
	endm

__R	macro
	call	dot
	call	dash
	call	dot_
	endm

__S	macro
	call	dot
	call	dot
	call	dot_
	endm

__T	macro
	call	dash_
	endm

__U	macro
	call	dot
	call	dot
	call	dash_
	endm

__V	macro
	call	dot
	call	dot
	call	dot
	call	dash_
	endm

__W	macro
	call	dot
	call	dash
	call	dash_
	endm

__X	macro
	call	dash
	call	dot
	call	dot
	call	dash_
	endm

__Y	macro
	call	dash
	call	dot
	call	dash
	call	dash_
	endm

__Z	macro
	call	dash
	call	dash
	call	dot
	call	dot_
	endm


__0	macro
	call	dash
	call	dash
	call	dash
	call	dash
	call	dash_
	endm

__1	macro
	call	dot
	call	dash
	call	dash
	call	dash
	call	dash_
	endm

__2	macro
	call	dot
	call	dot
	call	dash
	call	dash
	call	dash_
	endm

__3	macro
	call	dot
	call	dot
	call	dot
	call	dash
	call	dash_
	endm

__4	macro
	call	dot
	call	dot
	call	dot
	call	dot
	call	dash_
	endm

__5	macro
	call	dot
	call	dot
	call	dot
	call	dot
	call	dot_
	endm

__6	macro
	call	dash
	call	dot
	call	dot
	call	dot
	call	dot_
	endm

__7	macro
	call	dash
	call	dash
	call	dot
	call	dot
	call	dot_
	endm

__8	macro
	call	dash
	call	dash
	call	dash
	call	dot
	call	dot_
	endm

__9	macro
	call	dash
	call	dash
	call	dash
	call	dash
	call	dot_
	endm



__perio	macro
	call	dot
	call	dash
	call	dot
	call	dash
	call	dot
	call	dash_
	endm



;**********************************************************************
; Main Loop
;**********************************************************************

Main


	bcf	output


loop_forever

	__V	
	__V
	__V

	call	word_delay		; word delay..

	__C
	__A
	__L
	__L
	__S
	__I
	__G
	__N

	call	word_delay		; word delay..

	__B
	__E
	__A
	__C
	__O
	__N

	call	word_delay		; word delay..

	__F
	__R
	__E
	__Q


	call	word_delay		; word delay..

	__0
	__perio
	__1
	__W
	__A
	__T
	__T



	call	word_delay		; word delay..

	movlw	10				; Long dash delay..
	movwf	del_1	
	bsf	output				; key down
long_dash_loop
	call	word_delay		; word delay..
	decfsz	del_1, F
	goto 	long_dash_loop
	bcf	output				; key up
	

	call	word_delay		; word delay..

	goto 	loop_forever




;******************************************************************************
;	Dot/dash subroutines
;******************************************************************************

dot:						; normal dot
	bsf	output				; key down
	call	one_unit_delay	; wait one time unit
	bcf	output				; key up
	call	one_unit_delay	; wait one time unit
	retlw	0 
dot_:						; dot at end of character
	bsf	output
	call	one_unit_delay
	bcf	output
	call	three_unit_delay
	retlw	0 

dash:						; normal dash
	bsf	output
	call	three_unit_delay
	bcf	output
	call	one_unit_delay
	retlw	0 

dash_:						; dash at end of character
	bsf	output
	call	three_unit_delay
	bcf	output
	call	three_unit_delay
	retlw	0 



;**********************************************************************
; wait_Delay
; delay time approx 7 x 80ms
; 
;**********************************************************************
word_delay

	call three_unit_delay
	call three_unit_delay
	call one_unit_delay

	retlw	0  




;**********************************************************************
; three_unit_delay
; delay time approx ~240ms
; 
;**********************************************************************
three_unit_delay

	movlw	2	
	movwf	delay_2
	movlw	38
	movwf	delay_3
	movlw	15	
	movwf	delay_4
	
loop_13
loop_12
loop_11
	decfsz	delay_4, F
	goto 	loop_11

	decfsz	delay_3, F
	goto 	loop_12

	decfsz	delay_2, F
	goto 	loop_13

	retlw	0  


;**********************************************************************
; one_unit_delay
; delay time approx ~80ms
; 
;**********************************************************************
one_unit_delay

	movlw	1	
	movwf	delay_2
	movlw	68
	movwf	delay_3
	movlw	0xff
	movwf	delay_4
	
loop_23
loop_22
loop_21
	decfsz	delay_4, F
	goto 	loop_21

	decfsz	delay_3, F
	goto 	loop_22

	decfsz	delay_2, F
	goto 	loop_23

	retlw	0  


;********************



	END                       ; directive 'end of program'
